@@ -32,27 +32,27 @@ LatchD::LatchD( QObject* parent, QString type, QString id )
 {
     m_width  = 4;
     m_height = 10;
-    m_area = QRect(-(m_width*8/2),-(m_height*8/2), m_width*8, m_height*8 );
+    m_area = QRect(-m_width*8/2,-m_height*8/2, m_width*8, m_height*8 );
     
     m_tristate = true;
-    createOePin( "IR13OE", id+"-Pin_outEnable");
+    createOePin("IR13OE", id+"-Pin_outEnable");
 
     m_clkPin = new IoPin( 180, QPoint( -24,0 ), m_id+"-Pin_clock", 0, this, input );
     m_clkPin->setLabelColor( QColor( 0, 0, 0 ) );
-    setTrigger( InEnable );
+    LatchD::setTrigger( InEnable );
 
     m_channels = 0;
     setChannels( 8 );
 
     addPropGroup( { tr("Main"), {
-new IntProp   <LatchD>(  "Channels" , tr("Size")         ,"_Channels", this, &LatchD::channels,   &LatchD::setChannels, "uint" ),
-new StringProp<LatchD>( "Trigger", tr("Trigger Type")    ,""   , this, &LatchD::triggerStr, &LatchD::setTriggerStr, "enum" ),
-new BoolProp  <LatchD>( "Tristate" , tr("Tristate")      ,""   , this, &LatchD::tristate,   &LatchD::setTristate ),
-    }} );
+new IntProp <LatchD>("Channels" , tr("Size")        ,"_Channels", this, &LatchD::channels,   &LatchD::setChannels,0,"uint" ),
+new StrProp <LatchD>("Trigger"  , tr("Trigger Type"),""         , this, &LatchD::triggerStr, &LatchD::setTriggerStr,0,"enum" ),
+new BoolProp<LatchD>("Tristate" , tr("Tristate")    ,""         , this, &LatchD::tristate,   &LatchD::setTristate ),
+    }, groupNoCopy } );
     addPropGroup( { tr("Electric"), IoComponent::inputProps()
-+QList<ComProperty*>({new BoolProp<LatchD>( "Invert_Inputs", tr("Invert Inputs"),"", this, &LatchD::invertInps, &LatchD::setInvertInps )})
-                    +IoComponent::outputProps()+IoComponent::outputType() } );
-    addPropGroup( { tr("Edges"), IoComponent::edgeProps() } );
++QList<ComProperty*>({new BoolProp<LatchD>( "Invert_Inputs", tr("Invert Inputs"),"", this, &LatchD::invertInps, &LatchD::setInvertInps,propNoCopy )})
+                    +IoComponent::outputProps()+IoComponent::outputType(),0 } );
+    addPropGroup( { tr("Edges"), IoComponent::edgeProps(),0 } );
 }
 LatchD::~LatchD(){}
 
