@@ -250,12 +250,12 @@ void TextComponent::paint( QPainter* p, const QStyleOptionGraphicsItem* option,
 {
     Component::paint( p, option, widget );
 
-    QPen pen( QColor( 0, 0, 0 ), m_border, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
+    QPen pen( Qt::black, m_border, Qt::SolidLine, Qt::RoundCap, Qt::RoundJoin);
     p->setPen( pen );
 
     double opacity = p->opacity();
     p->setOpacity( opacity*m_opac );
-    p->fillRect( m_area, m_color );
+    p->drawRect( m_area );
     p->setOpacity( opacity );
 
     if( m_border > 0 )
