@@ -2,10 +2,11 @@
 #define TEXTCOMPONENT_H
 
 #include "component.h"
+#include "linkable.h"
 
 class LibraryItem;
 
-class MAINMODULE_EXPORT TextComponent : public Component
+class MAINMODULE_EXPORT TextComponent : public Component, public Linkable
 {
     public:
         TextComponent( QObject* parent, QString type, QString id );
@@ -28,34 +29,36 @@ class MAINMODULE_EXPORT TextComponent : public Component
         int  border() { return m_border; }
         void setBorder( int border ) { m_border = border; update(); }
         
+        QString getFont() { return m_font; }
+        void    setFont( QString font );
+
         int  fontSize() { return m_fontSize; }
         void setFontSize( int size );
+
+        QString fontColor() { return m_fontColor; }
+        void setFontColor( QString n );
+
+        QString colorStr() { return m_color.name(); }
+        void setColorStr( QString n );
         
         bool fixedW() { return m_fixedW; }
         void setFixedW( bool fixedW );
 
         QString getText();
         void    setText( QString text );
-        
-        QString getFont() { return m_font; }
-        void    setFont( QString font );
 
         qreal opac() { return m_opac; }
         void setOpac( qreal op );
 
-        QString getLinks();
-        void setLinks( QString links );
-
-        virtual void createLinks(QList<Component*>*compList ) override;
-
+        virtual void createLinks( QList<Component*>*compList ) override;
         virtual void compSelected( Component* comp ) override;
+        virtual void setLinkedString( QString str, int i=0 ) override;
 
         void paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWidget* widget ) override;
 
-
     public slots:
         void updateGeometry(int, int, int);
-        void linkComp();
+        void slotLinkComp() { Linkable::startLinking(); }
 
     protected:
         virtual void contextMenuEvent( QGraphicsSceneContextMenuEvent* event ) override;
@@ -64,9 +67,9 @@ class MAINMODULE_EXPORT TextComponent : public Component
         QGraphicsTextItem* m_text;
         QString m_textString;
 
-        QList<Component*> m_linkedComp;
-
         qreal m_opac;
+
+        bool m_changed;
         
         int  m_fontSize;
         int  m_docMargin;
@@ -77,6 +80,7 @@ class MAINMODULE_EXPORT TextComponent : public Component
         bool m_context;
         
         QString m_font;
+        QString m_fontColor;
 };
 
 #endif // TEXTCOMPONENT_H
