@@ -19,6 +19,9 @@ class MAINMODULE_EXPORT SwitchBase : public MechContact
 
         virtual void updateStep() override;
 
+        virtual void rotateAngle( double a ) override;
+        void rotateText( double angle );
+
         virtual void setHidden( bool hid, bool hidArea=false, bool hidLabel=false ) override;
 
         QString key() { return m_key; }
