@@ -75,6 +75,8 @@
 #include "scriptcpu.h"
 #include "scriptport.h"
 #include "scriptusart.h"
+#include "scriptspi.h"
+#include "scriptprop.h"
 
 #include "utils.h"
 
@@ -163,6 +165,7 @@ int McuCreator::processFile( QString fileName, bool main )
         else if( part == "intosc")      createIntOsc( &el );
         //else if( part == "extmem" )     createExtMem( &el );
         else if( part == "intmem" )     createIntMem( &el );
+
         else if( part == "include" )
         {
             error = processFile( el.attribute("file") );
@@ -181,9 +184,45 @@ int McuCreator::processFile( QString fileName, bool main )
         else if( m_core == "scripted" )
         {
             ScriptCpu* cpu = new ScriptCpu( mcu );
-            cpu->setPeriferals( m_scriptPerif );
             mcu->cpu = cpu;
             m_mcuComp->m_scripted = true;
+
+            if( root.hasAttribute("linkable")
+             && root.attribute("linkable") == "true" )
+                m_mcuComp->setScriptLinkable( cpu );
+
+            node = root.firstChild();
+            while( !node.isNull() )
+            {
+                QDomElement e = node.toElement();
+                QString  part = e.tagName();
+
+                if( part == "properties" )
+                {
+                    QString group = e.attribute("name");
+
+                    QList<ComProperty*> propList;
+                    m_mcuComp->addPropGroup( {group, propList} );
+
+                    QDomNode node = e.firstChild();
+                    while( !node.isNull() )
+                    {
+                        QDomElement el = node.toElement();
+
+                        if( el.tagName() == "property" )
+                        {
+                            QString name = el.attribute("name");
+                            QString type = el.attribute("type");
+
+                            cpu->addProperty( group, name, type );
+                        }
+                        node = node.nextSibling();
+                    }
+                }
+                node = node.nextSibling();
+            }
+            cpu->setPeriferals( m_scriptPerif );
+
             cpu->setScriptFile( m_basePath+"/"+root.attribute("script") );
         }
         else mcu->cpu = new McuCpu( mcu );
@@ -204,7 +243,7 @@ void McuCreator::createCfgWord( QDomElement* e )
     QString name = e->attribute("name");
     QString type = e->attribute("type");
 
-    ConfigWord* cfgWord;
+    ConfigWord* cfgWord = NULL;
     if( m_core == "Pic14" )  cfgWord = PicConfigWord::createCfgWord( mcu, name, type );
     if( !cfgWord ) return;
 
@@ -930,6 +969,7 @@ void McuCreator::createAcomp( QDomElement* e )
     if( !comp ) return;
 
     mcu->m_modules.emplace_back( comp );
+    mcu->m_comparator = comp;
     setConfigRegs( e, comp );
 
     QStringList pins = e->attribute( "pins" ).split(",");
@@ -998,21 +1038,30 @@ void McuCreator::createSpi( QDomElement* e )
 
     if     ( m_core == "AVR" )  m_spi = new AvrSpi( mcu, name );
     else if( m_core == "Pic14") m_spi = new PicSpi( mcu, name );
+    else if( m_core == "scripted"){
+        ScriptSpi* su = new ScriptSpi( mcu, name );
+        m_spi = su;
+        m_scriptPerif.push_back( su );
+    }
     else return;
 
     mcu->m_modules.emplace_back( m_spi );
 
     setConfigRegs( e, m_spi );
 
-    QString dataReg = e->attribute("dataregs");
-    m_spi->m_dataReg = mcu->getReg( dataReg );
-    watchRegNames( dataReg, R_WRITE, m_spi, &McuSpi::writeSpiReg, mcu );
-
-    QString statReg = e->attribute("statusreg");
-    m_spi->m_statReg = mcu->getReg( statReg );
-    watchRegNames( statReg, R_WRITE, m_spi, &McuSpi::writeStatus, mcu );
-
-    if( e->hasAttribute("interrupt") ) setInterrupt( e->attribute("interrupt"), m_spi );
+    if(  e->hasAttribute("dataregs") )
+    {
+        QString dataReg = e->attribute("dataregs");
+        m_spi->m_dataReg = mcu->getReg( dataReg );
+        watchRegNames( dataReg, R_WRITE, m_spi, &McuSpi::writeSpiReg, mcu );
+    }
+    if(  e->hasAttribute("statusreg") )
+    {
+        QString statReg = e->attribute("statusreg");
+        m_spi->m_statReg = mcu->getReg( statReg );
+        watchRegNames( statReg, R_WRITE, m_spi, &McuSpi::writeStatus, mcu );
+    }
+    if( e->hasAttribute("interrupt")  ) setInterrupt(  e->attribute("interrupt") , m_spi );
     if( e->hasAttribute("prescalers") ) setPrescalers( e->attribute("prescalers"), m_spi );
 
     QStringList pins = e->attribute("pins").remove(" ").split(",");
